@@ -45,6 +45,11 @@ public:
     int co2Emission = -1;
     std::vector<LoadInfo> loadInformation;
     RentalVehicle rentalVehicle;
+    Path path;
+    Vehicle departureVehicleLayout;
+    Platform departurePlatformLayout;
+    Vehicle arrivalVehicleLayout;
+    Platform arrivalPlatformLayout;
 
     int estimatedDistance() const;
 };
@@ -69,6 +74,11 @@ KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Route, route, setRoute)
 KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Disruption::Effect, disruptionEffect, setDisruptionEffect)
 KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, QStringList, notes, setNotes)
 KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, RentalVehicle, rentalVehicle, setRentalVehicle)
+KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Path, path, setPath)
+KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Vehicle, departureVehicleLayout, setDepartureVehicleLayout)
+KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Platform, departurePlatformLayout, setDeparturePlatformLayout)
+KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Vehicle, arrivalVehicleLayout, setArrivalVehicleLayout)
+KPUBLICTRANSPORT_MAKE_PROPERTY(JourneySection, Platform, arrivalPlatformLayout, setArrivalPlatformLayout)
 
 int JourneySectionPrivate::estimatedDistance() const
 {
@@ -88,7 +98,7 @@ int JourneySectionPrivate::estimatedDistance() const
     }
 
     d += Location::distance(startLat, startLon, to.latitude(), to.longitude());
-    return d;
+    return std::max(d, path.distance());
 }
 
 bool JourneySection::hasExpectedDepartureTime() const
@@ -227,6 +237,7 @@ const std::vector<Stopover>& JourneySection::intermediateStops() const
 
 std::vector<Stopover>&& JourneySection::takeIntermediateStops()
 {
+    d.detach();
     return std::move(d->intermediateStops);
 }
 
@@ -254,6 +265,9 @@ Stopover JourneySection::departure() const
     dep.setScheduledPlatform(scheduledDeparturePlatform());
     dep.setExpectedPlatform(expectedDeparturePlatform());
     dep.addNotes(notes());
+    dep.setDisruptionEffect(disruptionEffect());
+    dep.setVehicleLayout(departureVehicleLayout());
+    dep.setPlatformLayout(departurePlatformLayout());
     return dep;
 }
 
@@ -266,6 +280,9 @@ Stopover JourneySection::arrival() const
     arr.setExpectedArrivalTime(expectedArrivalTime());
     arr.setScheduledPlatform(scheduledArrivalPlatform());
     arr.setExpectedPlatform(expectedArrivalPlatform());
+    arr.setDisruptionEffect(disruptionEffect());
+    arr.setVehicleLayout(arrivalVehicleLayout());
+    arr.setPlatformLayout(arrivalPlatformLayout());
     return arr;
 }
 
@@ -413,6 +430,13 @@ JourneySection JourneySection::merge(const JourneySection &lhs, const JourneySec
     res.d->loadInformation = LoadUtil::merge(lhs.d->loadInformation, rhs.d->loadInformation);
     res.d->rentalVehicle = RentalVehicleUtil::merge(lhs.d->rentalVehicle, rhs.d->rentalVehicle);
 
+    res.d->path = lhs.d->path.isEmpty() ? rhs.d->path : lhs.d->path;
+
+    res.d->departureVehicleLayout = Vehicle::merge(lhs.d->departureVehicleLayout, rhs.d->departureVehicleLayout);
+    res.d->departurePlatformLayout = Platform::merge(lhs.d->departurePlatformLayout, rhs.d->departurePlatformLayout);
+    res.d->arrivalVehicleLayout = Vehicle::merge(lhs.d->arrivalVehicleLayout, rhs.d->arrivalVehicleLayout);
+    res.d->arrivalPlatformLayout = Platform::merge(lhs.d->arrivalPlatformLayout, rhs.d->arrivalPlatformLayout);
+
     return res;
 }
 
@@ -422,30 +446,47 @@ QJsonObject JourneySection::toJson(const JourneySection &section)
     if (section.mode() != Waiting) {
         const auto fromObj = Location::toJson(section.from());
         if (!fromObj.empty()) {
-            obj.insert(QStringLiteral("from"), fromObj);
+            obj.insert(QLatin1String("from"), fromObj);
         }
         const auto toObj = Location::toJson(section.to());
         if (!toObj.empty()) {
-            obj.insert(QStringLiteral("to"), toObj);
+            obj.insert(QLatin1String("to"), toObj);
         }
     }
     if (section.mode() == PublicTransport) {
         const auto routeObj = Route::toJson(section.route());
         if (!routeObj.empty()) {
-            obj.insert(QStringLiteral("route"), routeObj);
+            obj.insert(QLatin1String("route"), routeObj);
         }
         if (!section.intermediateStops().empty()) {
-            obj.insert(QStringLiteral("intermediateStops"), Stopover::toJson(section.intermediateStops()));
+            obj.insert(QLatin1String("intermediateStops"), Stopover::toJson(section.intermediateStops()));
         }
         if (!section.loadInformation().empty()) {
-            obj.insert(QStringLiteral("load"), LoadInfo::toJson(section.loadInformation()));
+            obj.insert(QLatin1String("load"), LoadInfo::toJson(section.loadInformation()));
         }
     }
     if (section.d->co2Emission < 0) {
         obj.remove(QLatin1String("co2Emission"));
     }
     if (section.rentalVehicle().type() != RentalVehicle::Unknown) {
-        obj.insert(QStringLiteral("rentalVehicle"), RentalVehicle::toJson(section.rentalVehicle()));
+        obj.insert(QLatin1String("rentalVehicle"), RentalVehicle::toJson(section.rentalVehicle()));
+    }
+
+    if (!section.path().isEmpty()) {
+        obj.insert(QLatin1String("path"), Path::toJson(section.path()));
+    }
+
+    if (!section.departureVehicleLayout().isEmpty()) {
+        obj.insert(QLatin1String("departureVehicleLayout"), Vehicle::toJson(section.departureVehicleLayout()));
+    }
+    if (!section.departurePlatformLayout().isEmpty()) {
+        obj.insert(QLatin1String("departurePlatformLayout"), Platform::toJson(section.departurePlatformLayout()));
+    }
+    if (!section.arrivalVehicleLayout().isEmpty()) {
+        obj.insert(QLatin1String("arrivalVehicleLayout"), Vehicle::toJson(section.arrivalVehicleLayout()));
+    }
+    if (!section.arrivalPlatformLayout().isEmpty()) {
+        obj.insert(QLatin1String("arrivalPlatformLayout"), Platform::toJson(section.arrivalPlatformLayout()));
     }
 
     if (obj.size() <= 3) { // only the disruption and mode enums and distance, ie. this is an empty object
@@ -468,6 +509,11 @@ JourneySection JourneySection::fromJson(const QJsonObject &obj)
     section.setIntermediateStops(Stopover::fromJson(obj.value(QLatin1String("intermediateStops")).toArray()));
     section.setLoadInformation(LoadInfo::fromJson(obj.value(QLatin1String("load")).toArray()));
     section.setRentalVehicle(RentalVehicle::fromJson(obj.value(QLatin1String("rentalVehicle")).toObject()));
+    section.setPath(Path::fromJson(obj.value(QLatin1String("path")).toObject()));
+    section.setDepartureVehicleLayout(Vehicle::fromJson(obj.value(QLatin1String("departureVehicleLayout")).toObject()));
+    section.setDeparturePlatformLayout(Platform::fromJson(obj.value(QLatin1String("departurePlatformLayout")).toObject()));
+    section.setArrivalVehicleLayout(Vehicle::fromJson(obj.value(QLatin1String("arrivalVehicleLayout")).toObject()));
+    section.setArrivalPlatformLayout(Platform::fromJson(obj.value(QLatin1String("arrivalPlatformLayout")).toObject()));
     return section;
 }
 
@@ -486,6 +532,7 @@ const std::vector<JourneySection>& Journey::sections() const
 
 std::vector<JourneySection>&& Journey::takeSections()
 {
+    d.detach();
     return std::move(d->sections);
 }
 
