@@ -34,6 +34,14 @@ private:
         return l;
     }
 
+    static bool hasRealtimeJourneyData(const std::vector<Journey> &journeys) {
+        return std::any_of(journeys.begin(), journeys.end(), [](const auto &jny) {
+            return std::any_of(jny.sections().begin(), jny.sections().end(), [](const auto &sec) {
+                return sec.hasExpectedDepartureTime() || sec.hasExpectedArrivalTime() || sec.hasExpectedDeparturePlatform() || sec.hasExpectedArrivalPlatform();
+            });
+        });
+    }
+
     static constexpr const auto TIMEOUT = 60000;
 
     KPublicTransport::Manager m_ptMgr;
@@ -88,6 +96,8 @@ private Q_SLOTS:
 
         QTest::newRow("au_nsw") << "au_nsw" << loc("Sydney Central", -33.88315, 151.20587) << loc("Sydney Internation Airport", -33.93503, 151.16603);
 
+        QTest::newRow("ch_zh_zvv") << "ch_zh_zvv" << loc("Zürich Flughafen", 47.45015, 8.56199 ) << loc("Zürich HB", 47.37833, 8.53912);
+
         QTest::newRow("de_bb_vbb") << "de_bb_vbb" << loc("Berlin Hauptbahnhof", 52.52509, 13.36946) << loc("Berlin Alexanderplatz", 52.52147, 13.41134);
         QTest::newRow("de_be_bvg") << "de_be_bvg" << loc("Berlin Hauptbahnhof", 52.52509, 13.36946) << loc("Berlin Alexanderplatz", 52.52147, 13.41134);
         QTest::newRow("de_bw_bwegt") << "de_bw_bwegt" << loc("Stuttgart Hbf", 48.78539, 9.18345) << loc("Herrenberg", 48.59392, 8.86275);
@@ -108,13 +118,15 @@ private Q_SLOTS:
         QTest::newRow("de_nw_avv") << "de_nw_avv" << loc("Aachen Hbf", 50.76784, 6.09130) << loc("Aachen West", 50.78025, 6.07124);
         // TODO de_nw_muenster
         QTest::newRow("de_nw_vrr") << "de_nw_vrr" << loc("Düsseldorf Hbf", 51.21991, 6.79419) << loc("Essen Hbf", 51.45127, 7.01388);
+        QTest::newRow("de_nw_vrs") << "de_nw_vrs" << loc("Köln Hbf", 50.94305, 6.95908) << loc("Bonn Hbf", 50.73203, 7.09719);
         QTest::newRow("de_nw_zks") << "de_nw_zks" << loc("Düsseldorf Hbf", 51.21991, 6.79419) << loc("Essen Hbf", 51.45127, 7.01388);
         QTest::newRow("de_rp_rolph") << "de_rp_rolph" << loc("Mainz Hbf", 50.00113, 8.25865) << loc("Kaiserslautern Hauptbahnhof", 49.43607, 7.76849);
+        QTest::newRow("de_rp_vrn") << "de_rp_vrn" << loc("Kaiserslautern Hauptbahnhof", 49.43607, 7.76849) << loc("Mannheim Hauptbahnhof", 49.47930, 8.46947);
         QTest::newRow("de_sh_sh") << "de_sh_sh" << loc("Hamburg Hauptbahnhof", 53.55299, 10.00702) << loc("Hamburg-Altona", 53.55284, 9.93569);
         QTest::newRow("de_sl_saarvv") << "de_sl_saarvv" << loc("Saarbrücken Hauptbahnhof", 49.24116, 6.99110) << loc("Saarlouis Hbf", 49.32766, 6.75103);
-        // TODO de_sn_vvo
+        QTest::newRow("de_sn_vvo") << "de_sn_vvo" << loc("Dresden Hbf", 51.04025, 13.73160) << loc("Chemnitz Hauptbahnhof", 50.83981, 12.93069);
         QTest::newRow("de_st_insa") << "de_st_insa" << loc("Leipzig Hbf", 51.34508, 12.38196) << loc("Leipzig S Bahnhof Messe", 51.39603, 12.38987);
-        // TODO de_th_vmt
+        QTest::newRow("de_th_vmt") << "de_th_vmt" << loc("Erfurt Hbf", 50.97227, 11.03790) << loc("Jena Paradies", 50.92491, 11.58725);
 
         QTest::newRow("fi_17_helsinki") << "fi_17_helsinki" << loc("Helsinki", 60.17174, 24.94148) << loc("Espoo", 60.20530, 24.65748);
 
@@ -162,6 +174,7 @@ private Q_SLOTS:
             LocationRequest req;
             req.setBackendIds({backend});
             req.setCoordinate(loc2.latitude(), loc2.longitude());
+            req.setMaximumResults(1);
             auto reply = m_ptMgr.queryLocation(req);
             QSignalSpy spy(reply, &LocationReply::finished);
             QVERIFY(spy.wait(TIMEOUT));
@@ -234,6 +247,7 @@ private Q_SLOTS:
             req.setBackendIds({backend});
             req.setFrom(loc1);
             req.setTo(loc2);
+            req.setMaximumResults(1);
             auto reply = m_ptMgr.queryJourney(req);
             QSignalSpy spy(reply, &JourneyReply::finished);
             QVERIFY(spy.wait(TIMEOUT));
@@ -241,6 +255,7 @@ private Q_SLOTS:
             QCOMPARE(reply->errorString(), QString());
             QCOMPARE(spy.size(), 1);
             QVERIFY(reply->result().size() > 0);
+            qDebug() << "Journey realtime data:" << hasRealtimeJourneyData(reply->result());
         }
     }
 };
